//[mahjong-utils](../../../index.md)/[mahjongutils.models](../index.md)/[Tile](index.md)/[advance](advance.md)

# advance

[common]\
fun [advance](advance.md)(step: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Tile](index.md)

该牌数字加上指定数字后得到的牌

#### Parameters

common

| | |
|---|---|
| step | 加减数字 |
